﻿using System;
using System.Configuration;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Collections.Generic;

namespace CustomZoomLevelSet
{
    public partial class TestForm : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
                Map1.CurrentExtent = new RectangleShape(-125, 72, 50, -46);
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                WorldMapKitWmsWebOverlay worldMapKitOverlay = new WorldMapKitWmsWebOverlay();
                Map1.CustomOverlays.Add(worldMapKitOverlay);

                this.AddSampleLayer();
                this.AddMarker();
             }
        }

        /// <summary>
        /// Creates the Lift map layer.
        /// </summary>
        private void AddSampleLayer()
        {
            // Define the columns that will contain data on the features
            List<FeatureSourceColumn> featureSourceColumns = new List<FeatureSourceColumn>();
            featureSourceColumns.Add(new FeatureSourceColumn("PopUpText", "string", 100));

            // Create the overlay
            InMemoryMarkerOverlay liftOverlay = new InMemoryMarkerOverlay("Lifts", featureSourceColumns);

            // Define the Marker General Properties
            // TODO: Add the popup to CSS
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.HasCloseButton = true;
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.AutoSize = true;
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.BackgroundColor = GeoColor.StandardColors.LightBlue;
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.BorderColor = GeoColor.StandardColors.Black;
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.BorderWidth = 1;
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.IsVisible = false;
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.AutoPan = true;

            // Define the Marker image
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage.ImageOffsetX = -10.5f;
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage.ImageOffsetY = -25f;
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage.ImageWidth = 21;
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage.ImageHeight = 25;

            //liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage = new WebImage("~/i/icon_lifts.png", 80, 80);
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage = new WebImage("~/i/home_32x32.png", 80, 80);
            liftOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.ContentHtml = "[#PopUpText#]";

            // Make it available all over the zoomlevels.
            liftOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            // Cluster icons at high zoom levels. This prevents points being displayed and bunched together unnecessarily
            liftOverlay.SuppressingGridSize = 50;

            // TODO: Add this to settings
            liftOverlay.IsVisibleInOverlaySwitcher = true;

            // liftOverlay.FeatureSource.Projection = baseMapProjection;
            this.Map1.CustomOverlays.Add(liftOverlay);
        }

        public void AddMarker()
        {
            // Get the Lift

            InMemoryMarkerOverlay liftOverlay = (InMemoryMarkerOverlay)this.Map1.CustomOverlays["Lifts"];
            float latitude = 52.653255130651f;
            float longitude = -8.586136783894f;
            string popUpText = "Pop up Text to be added";
            for (int i = 1; i <= 20; i++)
            {
                latitude = latitude + .05f;
                liftOverlay.Features.Add("Lift" + i.ToString(), new Feature(longitude, latitude, i.ToString(), new string[] { "PopUpText:" + popUpText }));
            }
        }
    }
}
